{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": "2stac",
            "id": "#2stac",
            "arguments": [
                "--result",
                {
                    "valueFrom": "$( inputs.result )"
                },
                "--metadata",
                {
                    "valueFrom": "$( inputs.metadata )"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "The resulting metadata of the previous model to insert in STAC",
                    "id": "#2stac/metadata",
                    "https://schema.org/name": "Input metadata file",
                    "https://schema.org/description": "The resulting metadata of the previous model to insert in STAC",
                    "https://schema.org/keywords": [
                        "metadata",
                        "File"
                    ],
                    "https://schema.org/fileFormat": "application/json"
                },
                {
                    "type": "File",
                    "doc": "The resulting file of the previous model to insert in STAC",
                    "id": "#2stac/result",
                    "https://schema.org/name": "Input result file",
                    "https://schema.org/description": "The resulting file of the previous model to insert in STAC",
                    "https://schema.org/keywords": [
                        "result",
                        "File"
                    ],
                    "https://schema.org/fileFormat": "*/*"
                }
            ],
            "requirements": [
                {
                    "dockerPull": "iliad-repository.inesctec.pt/2stac:1.0.0",
                    "class": "DockerRequirement"
                },
                {
                    "envDef": [
                        {
                            "envValue": "/srv/conda/envs/model-env/bin:/srv/conda/bin:/srv/conda/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin",
                            "envName": "PATH"
                        }
                    ],
                    "class": "EnvVarRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement"
                }
            ],
            "https://schema.org/name": "2Stac",
            "https://schema.org/description": "Transform the result into a STAC",
            "https://schema.org/keywords": [
                "stac",
                "metadata"
            ],
            "https://schema.org/programmingLanguage": "python",
            "https://schema.org/softwareVersion": "1.0.10",
            "https://schema.org/sourceOrganization": [
                {
                    "class": "https://schema.org/Organization",
                    "https://schema.org/name": "INESCTEC",
                    "https://schema.org/url": "https://inesctec.pt"
                },
                {
                    "class": "https://schema.org/Organization",
                    "https://schema.org/name": "D.U.TH",
                    "https://schema.org/url": "https://env.duth.gr"
                }
            ],
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Georgios Sylaios",
                    "https://schema.org/email": "gsylaios@env.duth.gr"
                },
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Nikolaos Kokkos",
                    "https://schema.org/email": "nikolaoskokkos@gmail.com"
                }
            ],
            "https://schema.org/contributor": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Miguel Correia",
                    "https://schema.org/email": "miguel.r.correia@inesctec.pt"
                }
            ],
            "https://schema.org/codeRepository": "https://pipe-drive.inesctec.pt/cwl/openoil_attached/2stac.cwl",
            "https://schema.org/dateCreated": "2023-04-21",
            "outputs": [
                {
                    "outputBinding": {
                        "glob": "."
                    },
                    "type": "Directory",
                    "doc": "STAC output",
                    "id": "#2stac/results"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "animation",
            "id": "#animation",
            "arguments": [
                "--file",
                {
                    "valueFrom": "$( inputs.file )"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "NetCDF file that contains the simulation",
                    "id": "#animation/file",
                    "https://schema.org/name": "Input simulation File",
                    "https://schema.org/description": "NetCDF file that contains the simulation",
                    "https://schema.org/keywords": [
                        "simulation",
                        "File"
                    ],
                    "https://schema.org/fileFormat": "application/x-netcdf; format=CF-1.4"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "doc": "The animation from the openoil simulation",
                    "outputBinding": {
                        "glob": "result/animation.gif"
                    },
                    "id": "#animation/animation",
                    "https://schema.org/fileFormat": "image/gif"
                }
            ],
            "requirements": [
                {
                    "dockerPull": "iliad-repository.inesctec.pt/openoil_animation:1.0.2",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "networkAccess": true,
                    "class": "NetworkAccess"
                },
                {
                    "class": "ResourceRequirement"
                }
            ],
            "https://schema.org/name": "openOil animation",
            "https://schema.org/description": "Animation of oil spill",
            "https://schema.org/keywords": [
                "oil spill",
                "openoil",
                "opendrift"
            ],
            "https://schema.org/programmingLanguage": "python",
            "https://schema.org/softwareVersion": "1.0.2",
            "https://schema.org/sourceOrganization": [
                {
                    "class": "https://schema.org/Organization",
                    "https://schema.org/name": "INESCTEC",
                    "https://schema.org/url": "https://inesctec.pt"
                },
                {
                    "class": "https://schema.org/Organization",
                    "https://schema.org/name": "D.U.TH",
                    "https://schema.org/url": "https://env.duth.gr"
                }
            ],
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Georgios Sylaios",
                    "https://schema.org/email": "gsylaios@env.duth.gr"
                },
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Nikolaos Kokkos",
                    "https://schema.org/email": "nikolaoskokkos@gmail.com"
                }
            ],
            "https://schema.org/contributor": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Miguel Correia",
                    "https://schema.org/email": "miguel.r.correia@inesctec.pt"
                }
            ],
            "https://schema.org/codeRepository": "https://pipe-drive.inesctec.pt/cwl/openoil_attached/animation.cwl",
            "https://schema.org/dateCreated": "2023-04-21"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "openoil",
            "id": "#openoil",
            "arguments": [
                "--lat",
                {
                    "valueFrom": "$( inputs.lat )"
                },
                "--lon",
                {
                    "valueFrom": "$( inputs.lon )"
                },
                "--time",
                {
                    "valueFrom": "$( inputs.time )"
                },
                "--oiltype",
                {
                    "valueFrom": "$( inputs.oiltype )"
                },
                "--duration",
                {
                    "valueFrom": "$( inputs.duration )"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "doc": "The simulation duration",
                    "id": "#openoil/duration",
                    "https://schema.org/name": "Input duration int",
                    "https://schema.org/description": "The simulation duration",
                    "https://schema.org/keywords": [
                        "duration",
                        "int"
                    ]
                },
                {
                    "type": "float",
                    "doc": "The latitude of the study area",
                    "id": "#openoil/lat",
                    "https://schema.org/name": "Input lat float",
                    "https://schema.org/description": "The latitude of the study area",
                    "https://schema.org/keywords": [
                        "lat",
                        "float"
                    ]
                },
                {
                    "type": "float",
                    "doc": "The longitude of the study area",
                    "id": "#openoil/lon",
                    "https://schema.org/name": "Input lon float",
                    "https://schema.org/description": "The longitude of the study area",
                    "https://schema.org/keywords": [
                        "lon",
                        "float"
                    ]
                },
                {
                    "type": "string",
                    "doc": "The type of the oil to run the simulation",
                    "id": "#openoil/oiltype",
                    "https://schema.org/name": "Input oiltype string",
                    "https://schema.org/description": "The type of the oil to run the simulation",
                    "https://schema.org/keywords": [
                        "oiltype",
                        "string"
                    ]
                },
                {
                    "type": "string",
                    "doc": "The start time of the simulation",
                    "id": "#openoil/time",
                    "https://schema.org/name": "Input time string",
                    "https://schema.org/description": "The start time of the simulation. Type dd-mm-yyyy",
                    "https://schema.org/keywords": [
                        "time",
                        "string"
                    ]
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "result/metadata.json"
                    },
                    "doc": "metadata description",
                    "id": "#openoil/metadata",
                    "https://schema.org/fileFormat": "application/json"
                },
                {
                    "format": "http://www.opengis.net/def/media-type/ogc/1.0/netcdf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "result/simulation.nc"
                    },
                    "id": "#openoil/simulation",
                    "https://schema.org/fileFormat": "application/x-netcdf; format=CF-1.4"
                }
            ],
            "requirements": [
                {
                    "dockerPull": "iliad-repository.inesctec.pt/openoil_simulation:1.0.11",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "networkAccess": true,
                    "class": "NetworkAccess"
                },
                {
                    "class": "ResourceRequirement"
                }
            ],
            "https://schema.org/name": "openOil model",
            "https://schema.org/description": "Simulation of oil spill",
            "https://schema.org/keywords": [
                "oil spill",
                "openoil",
                "opendrift"
            ],
            "https://schema.org/programmingLanguage": "python",
            "https://schema.org/softwareVersion": "1.0.11",
            "https://schema.org/sourceOrganization": [
                {
                    "class": "https://schema.org/Organization",
                    "https://schema.org/name": "INESCTEC",
                    "https://schema.org/url": "https://inesctec.pt"
                },
                {
                    "class": "https://schema.org/Organization",
                    "https://schema.org/name": "D.U.TH",
                    "https://schema.org/url": "https://env.duth.gr"
                }
            ],
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Georgios Sylaios",
                    "https://schema.org/email": "gsylaios@env.duth.gr"
                },
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Nikolaos Kokkos",
                    "https://schema.org/email": "nikolaoskokkos@gmail.com"
                }
            ],
            "https://schema.org/contributor": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Miguel Correia",
                    "https://schema.org/email": "miguel.r.correia@inesctec.pt"
                }
            ],
            "https://schema.org/codeRepository": "https://pipe-drive.inesctec.pt/cwl/openoil_attached/simulation.cwl",
            "https://schema.org/dateCreated": "2023-04-21"
        },
        {
            "class": "Workflow",
            "id": "#main",
            "doc": "Animation of an oil spill with openoil",
            "inputs": [
                {
                    "type": "int",
                    "doc": "The simulation duration",
                    "id": "#main/duration",
                    "https://schema.org/name": "Input duration int",
                    "https://schema.org/description": "The simulation duration",
                    "https://schema.org/keywords": [
                        "duration",
                        "int"
                    ]
                },
                {
                    "type": "float",
                    "doc": "The latitude of the study area",
                    "id": "#main/lat",
                    "https://schema.org/name": "Input lat float",
                    "https://schema.org/description": "The latitude of the study area",
                    "https://schema.org/keywords": [
                        "lat",
                        "float"
                    ]
                },
                {
                    "type": "float",
                    "doc": "The longitude of the study area",
                    "id": "#main/lon",
                    "https://schema.org/name": "Input lon float",
                    "https://schema.org/description": "The longitude of the study area",
                    "https://schema.org/keywords": [
                        "lon",
                        "float"
                    ]
                },
                {
                    "type": "string",
                    "doc": "The type of the oil to run the simulation",
                    "id": "#main/oiltype",
                    "https://schema.org/name": "Input oiltype string",
                    "https://schema.org/description": "The type of the oil to run the simulation",
                    "https://schema.org/keywords": [
                        "oiltype",
                        "string"
                    ]
                },
                {
                    "type": "string",
                    "doc": "The start time of the simulation",
                    "id": "#main/time",
                    "https://schema.org/name": "Input time string",
                    "https://schema.org/description": "The start time of the simulation. Type dd-mm-yyyy",
                    "https://schema.org/keywords": [
                        "time",
                        "string"
                    ]
                }
            ],
            "steps": [
                {
                    "run": "#2stac",
                    "in": [
                        {
                            "source": "#main/simulation/metadata",
                            "id": "#main/2stac/metadata"
                        },
                        {
                            "source": "#main/animation/animation",
                            "id": "#main/2stac/result"
                        }
                    ],
                    "out": [
                        "#main/2stac/results"
                    ],
                    "id": "#main/2stac"
                },
                {
                    "run": "#animation",
                    "in": [
                        {
                            "source": "#main/simulation/simulation",
                            "id": "#main/animation/file"
                        }
                    ],
                    "out": [
                        "#main/animation/animation"
                    ],
                    "id": "#main/animation"
                },
                {
                    "run": "#openoil",
                    "in": [
                        {
                            "source": "#main/duration",
                            "id": "#main/simulation/duration"
                        },
                        {
                            "source": "#main/lat",
                            "id": "#main/simulation/lat"
                        },
                        {
                            "source": "#main/lon",
                            "id": "#main/simulation/lon"
                        },
                        {
                            "source": "#main/oiltype",
                            "id": "#main/simulation/oiltype"
                        },
                        {
                            "source": "#main/time",
                            "id": "#main/simulation/time"
                        }
                    ],
                    "out": [
                        "#main/simulation/simulation",
                        "#main/simulation/metadata"
                    ],
                    "id": "#main/simulation"
                }
            ],
            "outputs": [
                {
                    "id": "#main/wf_outputs",
                    "outputSource": [
                        "#main/2stac/results"
                    ],
                    "type": "Directory"
                }
            ],
            "https://schema.org/name": "openOil pipeline",
            "https://schema.org/description": "Simulation and animation of oil spill",
            "https://schema.org/keywords": [
                "oil spill",
                "openoil",
                "opendrift",
                "animation"
            ],
            "https://schema.org/programmingLanguage": "python",
            "https://schema.org/softwareVersion": "1.0.10",
            "https://schema.org/sourceOrganization": [
                {
                    "class": "https://schema.org/Organization",
                    "https://schema.org/name": "INESCTEC",
                    "https://schema.org/url": "https://inesctec.pt"
                },
                {
                    "class": "https://schema.org/Organization",
                    "https://schema.org/name": "D.U.TH",
                    "https://schema.org/url": "https://env.duth.gr"
                }
            ],
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Georgios Sylaios",
                    "https://schema.org/email": "gsylaios@env.duth.gr"
                },
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Nikolaos Kokkos",
                    "https://schema.org/email": "nikolaoskokkos@gmail.com"
                }
            ],
            "https://schema.org/contributor": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Miguel Correia",
                    "https://schema.org/email": "miguel.r.correia@inesctec.pt"
                }
            ]
        }
    ],
    "cwlVersion": "v1.2",
    "$namespaces": {
        "s": "https://schema.org/",
        "ogc": "http://www.opengis.net/def/media-type/ogc/1.0/"
    }
}
